@@ -5,6 +5,13 @@
 #include <stdio.h>
 #include "ppm.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+#if 0
+} /* to fake out automatic code indenters */
+#endif
+
 enum colornameFormat {PAM_COLORNAME_ENGLISH = 0,
                       PAM_COLORNAME_HEXOK   = 1};
 
@@ -30,4 +37,7 @@ pm_parse_dictionary_name(const char       colorname[],
                          int        const closeOk,
                          pixel *    const colorP);
 
+#ifdef __cplusplus
+}
+#endif
 #endif
